OC.L10N.register(
    "mail",
    {
    "Important" : "Važno",
    "Work" : "Posao",
    "Personal" : "Osobno",
    "Mail" : "E-pošta",
    "Save" : "Spremi",
    "Name" : "Ime",
    "Password" : "Lozinka",
    "None" : "Ništa",
    "SMTP Password" : "SMPT Lozinka",
    "Cancel" : "Otkaži",
    "Accounts" : "Accounts",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Delete" : "Obriši",
    "Search" : "Search",
    "Send" : "Pošalji",
    "Ok" : "Ok",
    "Choose" : "Izaberite",
    "Favorite" : "Favorit",
    "Edit tags" : "Izmjeni oznake",
    "Attendees" : "Sudionici",
    "Description" : "Opis",
    "Create" : "Ustvari",
    "Select" : "Select",
    "Comment" : "Komentar",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "Today" : "Danas",
    "Other" : "Ostali",
    "Move" : "Move",
    "Rename" : "Preimenuj",
    "Add" : "Dodaj",
    "Close" : "Zatvori",
    "Date" : "Date",
    "Tag already exists" : "Oznaka već postoji",
    "Help" : "Pomoć",
    "Actions" : "Radnje",
    "delete" : "izbriši",
    "Edit" : "Izmjeni",
    "User" : "User",
    "Port" : "Priključak",
    "Valid until" : "Validno do",
    "Group" : "Grupa",
    "Shared" : "Podijeljen",
    "All" : "Sve",
    "Favorites" : "Favoriti"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
